%global momorel 1

%define nspr_version 4.8
%define nss_version 3.12.7
%define cairo_version 1.6.0
%define freetype_version 2.1.9
%define sqlite_version 3.6.14
%define libnotify_version 0.4
%define build_langpacks 1
%define moz_objdir objdir-tb
%define thunderbird_app_id \{3550f703-e582-4d05-9a08-453d09bdfdc6\} 

# The tarball is pretty inconsistent with directory structure.
# Sometimes there is a top level directory.  That goes here.
#
# IMPORTANT: If there is no top level directory, this should be 
# set to the cwd, ie: '.'
#%define tarballdir .
%define tarballdir comm-1.9.2

%define version_internal  3.1
%define mozappdir         %{_libdir}/%{name}-%{version_internal}

Summary:        Mozilla Thunderbird mail/newsgroup client
Name:           thunderbird
Version:        3.1.3
Release:        %{momorel}m%{?dist}
URL:            http://www.mozilla.org/projects/thunderbird/
License:        MPLv1.1 or GPLv2+ or LGPLv2+
Group:          Applications/Internet
Source0:        http://releases.mozilla.org/pub/mozilla.org/thunderbird/releases/%{version}/source/thunderbird-%{version}.source.tar.bz2
NoSource:       0
%if %{build_langpacks}
Source1:        shredder-langpacks-%{version}-20100907.tar.xz
%endif
# Config file for compilation
Source10:       thunderbird-mozconfig
# Default preferences for Thunderbird
Source12:       thunderbird-momonga-default-prefs.js
# Desktop file
Source20:       thunderbird.desktop
# TB execute script
Source21:       thunderbird.sh.in
# Script called when user click on link in message
Source30:       thunderbird-open-browser.sh
# Finds requirements provided outside of the current file set
Source100:      find-external-requires

# Momonga
Source1000:     mailnews.png

# Fix for version issues
Patch0:         thunderbird-version.patch
# Fix for jemalloc
Patch1:         mozilla-jemalloc.patch
# Fix for installation fail when building with dynamic linked libraries
Patch2:         thunderbird-shared-error.patch
# Fixes gcc complain that nsFrame::delete is protected
Patch4:         xulrunner-1.9.2.1-build.patch
# Fix missing includes for crash reporter, remove in 3.1 final
Patch6:         remove-static.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  nspr-devel >= %{nspr_version}
BuildRequires:  nss-devel >= %{nss_version}
BuildRequires:  cairo-devel >= %{cairo_version}
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-devel >= 8a
BuildRequires:  zip
BuildRequires:  bzip2-devel
BuildRequires:  zlib-devel
BuildRequires:  libIDL-devel
BuildRequires:  gtk2-devel
BuildRequires:  gnome-vfs2-devel
BuildRequires:  libgnome-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  krb5-devel
BuildRequires:  pango-devel
BuildRequires:  freetype-devel >= %{freetype_version}
BuildRequires:  libXt-devel
BuildRequires:  libXrender-devel
BuildRequires:  hunspell-devel
BuildRequires:  sqlite-devel >= %{sqlite_version}
BuildRequires:  startup-notification-devel
BuildRequires:  alsa-lib-devel
BuildRequires:  autoconf213
BuildRequires:  desktop-file-utils
Requires:       mozilla-filesystem
Requires:       nspr >= %{nspr_version}
Requires:       nss >= %{nss_version}
Requires:       sqlite >= %{sqlite_version}

AutoProv: 0
%define _use_internal_dependency_generator 0
%define __find_requires %{SOURCE100}

%description
Mozilla Thunderbird is a standalone mail and newsgroup client.

#===============================================================================

%prep
%setup -q -c
cd %{tarballdir}

sed -e 's/__RPM_VERSION_INTERNAL__/%{version_internal}/' %{P:%%PATCH0} \
    > version.patch
%{__patch} -p1 -b --suffix .version --fuzz=0 < version.patch

%patch1 -p0 -b .jemalloc
%patch2 -p1 -b .shared-error
%patch4 -p1 -b .protected
%patch6 -p1 -b .static

%{__rm} -f .mozconfig
%{__cp} %{SOURCE10} .mozconfig

#===============================================================================

%build
cd %{tarballdir}

INTERNAL_GECKO=%{version_internal}
MOZ_APP_DIR=%{mozappdir}

# Build with -Os as it helps the browser; also, don't override mozilla's warning
# level; they use -Wall but disable a few warnings that show up _everywhere_
MOZ_OPT_FLAGS=$(echo $RPM_OPT_FLAGS | %{__sed} -e 's/-O2/-Os/' -e 's/-Wall//')

export RPM_OPT_FLAGS=$MOZ_OPT_FLAGS
export PREFIX='%{_prefix}'
export LIBDIR='%{_libdir}'

%define moz_make_flags -j1
%ifarch ppc ppc64 s390 s390x
%define moz_make_flags -j1
%else
%define moz_make_flags %{?_smp_mflags}
%endif

export LDFLAGS="-Wl,-rpath,%{mozappdir}"
export MAKE="gmake %{moz_make_flags}"
make -f client.mk build

#===============================================================================

%install
%{__rm} -rf $RPM_BUILD_ROOT
cd %{tarballdir}

INTERNAL_GECKO=%{version_internal}

INTERNAL_APP_NAME=%{name}-${INTERNAL_GECKO}
MOZ_APP_DIR=%{_libdir}/${INTERNAL_APP_NAME}

cd %{moz_objdir}
DESTDIR=$RPM_BUILD_ROOT make install

# install icons
cd -
for size in 16x16 22x22 24x24 32x32 36x36 48x48 64x64 72x72 96x96
do
    %{__mkdir_p} $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${size}/apps
    convert -resize ${size} %{SOURCE1000} \
      $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${size}/apps/%{name}.png
done
%{__mkdir_p} $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/256x256/apps
%{__install} -m 644 %{SOURCE1000} \
  $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/256x256/apps/%{name}.png


desktop-file-install --vendor mozilla \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --add-category Network \
  --add-category Email \
  %{SOURCE20}


# set up the thunderbird start script
rm -f $RPM_BUILD_ROOT/%{_bindir}/thunderbird
%{__cat} %{SOURCE21} | %{__sed} -e 's,TBIRD_VERSION,%{version_internal},g' > \
  $RPM_BUILD_ROOT%{_bindir}/thunderbird
%{__chmod} 755 $RPM_BUILD_ROOT/%{_bindir}/thunderbird

install -Dm755 %{SOURCE30} $RPM_BUILD_ROOT/%{mozappdir}/open-browser.sh
%{__sed} -i -e 's|LIBDIR|%{_libdir}|g' $RPM_BUILD_ROOT/%{mozappdir}/open-browser.sh

# set up our default preferences
%{__cat} %{SOURCE12} | %{__sed} -e 's,THUNDERBIRD_RPM_VR,%{version}-%{release},g' \
                                -e 's,COMMAND,%{mozappdir}/open-browser.sh,g' > \
        $RPM_BUILD_ROOT/mo-default-prefs
%{__install} -D $RPM_BUILD_ROOT/mo-default-prefs $RPM_BUILD_ROOT/%{mozappdir}/greprefs/all-momonga.js
%{__install} -D $RPM_BUILD_ROOT/mo-default-prefs $RPM_BUILD_ROOT/%{mozappdir}/defaults/pref/all-momonga.js
%{__rm} $RPM_BUILD_ROOT/mo-default-prefs

%{__rm} -f $RPM_BUILD_ROOT%{_bindir}/thunderbird-config

# own mozilla plugin dir (#135050)
%{__mkdir_p} $RPM_BUILD_ROOT%{_libdir}/mozilla/plugins

# own extension directories
%{__mkdir_p} $RPM_BUILD_ROOT%{_datadir}/mozilla/extensions/%{thunderbird_app_id}
%{__mkdir_p} $RPM_BUILD_ROOT%{_libdir}/mozilla/extensions/%{thunderbird_app_id}

# Install langpacks
%{__rm} -f %{name}.lang # Delete for --short-circuit option
touch %{name}.lang
%if %{build_langpacks}
%{__mkdir_p} $RPM_BUILD_ROOT%{mozappdir}/langpacks
%{__tar} xjf %{SOURCE1}
for langpack in `ls thunderbird-langpacks/*.xpi`; do
  language=`basename $langpack .xpi`
  extensiondir=$RPM_BUILD_ROOT%{mozappdir}/langpacks/langpack-$language@thunderbird.mozilla.org
  %{__mkdir_p} $extensiondir
  unzip $langpack -d $extensiondir
  find $extensiondir -type f | xargs chmod 644

  tmpdir=`mktemp -d %{name}.XXXXXXXX`
  langtmp=$tmpdir/%{name}/langpack-$language
  %{__mkdir_p} $langtmp
  jarfile=$extensiondir/chrome/$language.jar
  unzip $jarfile -d $langtmp

  find $langtmp -type f | xargs chmod 644
  %{__rm} -rf $jarfile
  cd $langtmp
  zip -r -D $jarfile locale
  %{__rm} -rf locale
  cd -
  %{__rm} -rf $tmpdir

  language=`echo $language | sed -e 's/-/_/g'`
  extensiondir=`echo $extensiondir | sed -e "s,^$RPM_BUILD_ROOT,,"`
  echo "%%lang($language) $extensiondir" >> %{name}.lang
done
%{__rm} -rf thunderbird-langpacks
%endif # build_langpacks

# Copy over the LICENSE
cd mozilla
install -c -m 644 LICENSE $RPM_BUILD_ROOT%{mozappdir}
cd -

# Use the system hunspell dictionaries
%{__rm} -rf $RPM_BUILD_ROOT/%{mozappdir}/dictionaries
ln -s %{_datadir}/myspell $RPM_BUILD_ROOT%{mozappdir}/dictionaries

# ghost files
%{__mkdir_p} $RPM_BUILD_ROOT%{mozappdir}/components
touch $RPM_BUILD_ROOT%{mozappdir}/components/compreg.dat
touch $RPM_BUILD_ROOT%{mozappdir}/components/xpti.dat

#===============================================================================

%clean
%{__rm} -rf $RPM_BUILD_ROOT

#===============================================================================

%post
update-desktop-database &> /dev/null || :
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

#===============================================================================

%postun
update-desktop-database &> /dev/null || :
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

#===============================================================================

%files -f %{tarballdir}/%{name}.lang
%defattr(-,root,root,-)
%attr(755,root,root) %{_bindir}/thunderbird
%attr(644,root,root) %{_datadir}/applications/mozilla-thunderbird.desktop
%dir %{_datadir}/mozilla/extensions/%{thunderbird_app_id}
%dir %{_libdir}/mozilla/extensions/%{thunderbird_app_id}
%dir %{mozappdir}
%doc %{mozappdir}/LICENSE
%{mozappdir}/chrome
%dir %{mozappdir}/components
%ghost %{mozappdir}/components/compreg.dat
%ghost %{mozappdir}/components/xpti.dat
%{mozappdir}/components/components.list
%{mozappdir}/components/*.so
%{mozappdir}/components/*.xpt
%attr(644,root,root) %{mozappdir}/components/*.js
%{mozappdir}/defaults
%{mozappdir}/dictionaries
%dir %{mozappdir}/extensions
%{mozappdir}/extensions/{972ce4c6-7e08-4474-a285-3208198ce6fd}
%dir %{mozappdir}/langpacks
%{mozappdir}/greprefs
%{mozappdir}/isp
%{mozappdir}/mozilla-xremote-client
%{mozappdir}/open-browser.sh
%{mozappdir}/res
%{mozappdir}/run-mozilla.sh
%{mozappdir}/thunderbird-bin
%{mozappdir}/thunderbird
%{mozappdir}/*.so
%dir %{mozappdir}/modules
%{mozappdir}/modules/*.jsm
%{mozappdir}/modules/*.js
%dir %{mozappdir}/modules/gloda
%{mozappdir}/modules/gloda/*.js
%dir %{mozappdir}/modules/activity
%{mozappdir}/modules/activity/*.js
%{mozappdir}/README.txt
%{mozappdir}/platform.ini
%{mozappdir}/application.ini
%exclude %{mozappdir}/removed-files
%{_datadir}/icons/hicolor/*/apps/thunderbird.png

#===============================================================================

%changelog
* Wed Sep  8 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.1.3-1m)
- [SECURITY] CVE-2010-2764 CVE-2010-2769 CVE-2010-2768 CVE-2010-2762
- [SECURITY] CVE-2010-2770 CVE-2010-2766 CVE-2010-3167 CVE-2010-3168
- [SECURITY] CVE-2010-2760 CVE-2010-3166 CVE-2010-3131 CVE-2010-2767
- [SECURITY] CVE-2010-2765 CVE-2010-3169
- update to 3.1.3

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (3.1.2-2m)
- full rebuild for mo7 release

* Fri Aug 20 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.1.2-1m)
- update to 3.1.2

* Thu Jul 22 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.1.1-1m)
- [SECURITY] CVE-2010-2754 CVE-2010-0654 CVE-2010-1210 CVE-2010-1207
- [SECURITY] CVE-2010-1213 CVE-2010-1205 CVE-2010-2753 CVE-2010-2752
- [SECURITY] CVE-2010-1215 CVE-2010-1211
- update to 3.1.1

* Sat Jun 26 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.1-1m)
- update to 3.1

* Mon Jun 21 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0.5-1m)
- [SECURITY] CVE-2010-1121 CVE-2010-1200 CVE-2010-1201 CVE-2010-1202
- [SECURITY] CVE-2010-1203 CVE-2010-1196 CVE-2010-1199
- update to 3.0.5

* Sat Apr 10 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0.4-2m)
- rebuild against libjpeg-8a

* Wed Mar 31 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0.4-1m)
- [SECURITY] CVE-2010-0173 CVE-2010-0174 CVE-2010-0175 CVE-2010-0176
- [SECURITY] CVE-2010-0182
- update to 3.0.4

* Tue Mar  2 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0.3-1m)
- update to 3.0.3

* Sun Feb 28 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0.2-1m)
- [SECURITY] CVE-2010-0159 CVE-2009-1571
- update to 3.0.2
-- merged imap-unread.patch

* Tue Jan 26 2010 Masanobu Sato <satoshiga@momonga-linux.org>
- (3.0.1-2m)
- add patch to fix false marked as unread for IMAP server(Bug 540554)
-- maybe not fix it perfectly, have to more update.

* Sat Jan 23 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0.1-1m)
- [SECURITY] CVE-2009-3389 CVE-2009-3388
- update to 3.0.1

* Fri Dec 11 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.0-2m)
- merge from T4R
-- 
-- * Thu Dec 10 2009 Masanobu Sato <satoshiga@momonga-linux.org>
-- - (3.0-1m)
-- - update to 3.0
-- 
-- * Fri Dec  4 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
-- - (3.0-0.4.2m)
-- - update langpacks
-- 
-- * Wed Dec  2 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
-- - (3.0-0.4.1m)
-- - update to 3.0rc2
-- 
-- * Thu Nov 26 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
-- - (3.0-0.3.1m)
-- - update to 3.0rc1
-- 
-- * Wed Oct  7 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
-- - (3.0-0.2.1m)
-- - update to 3.0b4
-- 
-- * Thu Jun 18 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
-- - (3.0-0.1.1m)
-- - sync with Fedora 11 (3.0-2.4), but official_branding is 0
-- -- 
-- -- * Wed May 13 2009 Christopher Aillon <caillon@redhat.com> - 3.0-2.4
-- -- - Update to a post beta2 snapshot
-- -- 
-- -- * Wed May 13 2009 Christopher Aillon <caillon@redhat.com> - 3.0-2.3
-- -- - Fix startup crash when imap server sends list response with trailing delimiter
-- -- 
-- -- * Mon Mar 30 2009 Jan Horak <jhorak@redhat.com> - 3.0-2.2
-- -- - Fixed open-browser.sh to use xdg-open instead of gnome-open
-- -- 
-- -- * Mon Mar 23 2009 Christopher Aillon <caillon@redhat.com> - 3.0-2.1
-- -- - Disable the default app nag dialog
-- -- 
-- -- * Tue Mar 17 2009 Jan Horak <jhorak@redhat.com> - 3.0-2
-- -- - Fixed clicked link does not open in browser (#489120)
-- -- - Fixed missing help in thunderbird (#488885)
-- -- 
-- -- * Mon Mar  2 2009 Jan Horak <jhorak@redhat.com> - 3.0-1
-- -- - Update to 3.0 beta2
-- -- - Added Patch2 to build correctly when building with --enable-shared option 

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.23-6m)
- rebuild against gcc-4.4 and glibc-2.11

* Wed Oct 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.23-5m)
- temporarily drop -Wp,-D_FORTIFY_SOURCE=2

* Sat Sep 12 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (2.0.0.23-4m)
- rebuild against libjpeg-7

* Sun Aug 30 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.23-3m)
- add ac_cv_visibility_pragma=no to mozconfig as well as Fedora 10 (2.0.0.23-1)

* Sat Aug 29 2009 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.23-2m)
- update to 2.0.0.23 langpacks

* Sat Aug 29 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.23-1m)
- update to 2.0.0.23, but langpacks are still old
- resolved sqlite3 linking issue
-- http://groups.google.com/group/mozilla.dev.apps.thunderbird/msg/af0a5dad2de5a5a5

* Sun Jul 12 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.22-2m)
- now unofficial branding. the name is Mail/News. it is simple.
- use mailnews.png (Source22) as icon
- do not install official default.xpm
- svn add generate-mailnews-langpacks.sh
- License: MPLv1.1 or GPLv2+ or LGPLv2+

* Wed Jun 24 2009 Masanobu Sato <satoshiga@momonga-linux.org> 
- (2.0.0.22-1m)
- update to 2.0.0.22
- [SECURITY] MFSA 2009-14, 16, 17, 18, 19, 24, 27, 29, 31, 32, 33

* Thu Mar 19 2009 Masanobu Sato <satoshiga@momonga-linux.org> 
- (2.0.0.21-1m)
- update to 2.0.0.21
- [SECURITY] MFSA 2009-07, 09, 10

* Sat Feb 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.19-4m)
- apply gcc44 patch

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.19-3m)
- rebuild against rpm-4.6

* Fri Jan  9 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.0.0.19-2m)
- update Patch102 for fuzz=0

* Wed Dec 31 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.19-1m)
- update to 2.0.0.19
- [SECURITY] MFSA 2008-60, 61, 64, 65, 66, 67, 68

* Fri Nov 21 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.18-1m)
- update to 2.0.0.18
- [SECURITY] MFSA 2008-59, 58 ,56, 55, 52, 50, 48

* Fri Sep 26 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.17-1m)
- update to 2.0.0.17
- [SECURITY] MFSA 2008-46, 44, 43, 42, 41, 38, 37

* Thu Jul 24 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.16-1m)
- update to 2.0.0.16
- [SECURITY] MFSA 2008-34, 33, 31, 29, 26, 25, 24, 21

* Sun Jun  1 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (2.0.0.14-2m)
- add Prereq: desktop-file-utils

* Sat May  3 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.14-1m)
- update to 2.0.0.14
- [SECURITY] MFSA 2008-14, MSFA 2008-15 

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.0.0.12-2m)
- rebuild against gcc43

* Thu Feb 28 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.12-1m)
- update to 2.0.0.12 and import some patches from FC
- [SECURITY] MFSA 2008-12,MFSA 2008-07,MFSA 2008-05,MFSA 2008-03,MFSA 2008-01

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.0.0.9-3m)
- %%NoSource -> NoSource

* Sun Jan  6 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- add patch for gcc43

* Fri Nov 16 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.9-1m)
- [SECURITY] CVE-2007-5339 CVE-2007-5340 (MFSA2007-29)
- [SECURITY] CVE-2007-4841 (MFSA2007-36)
- update to 2.0.0.9

* Fri Aug  3 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.6-1m)
- update to 2.0.0.6
- [SECURITY] MFSA 2007-26 MFSA 2007-27

* Sun Jul 22 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.5-1m)
- update to 2.0.0.5

* Fri May 11 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.4-1m)
- update to 2.0.0.4

* Fri May 11 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.0.0-1m)
- update to 2.0.0.0, sync with FC

* Sat Mar 31 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.5.0.9-3m)
- BuildRequires: freetype2-devel -> freetype-devel

* Mon Jan 22 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (1.5.0.9-2m)
- add thunderbird-1.5.0.9-bug367203.patch for drag and drop broken at gtk+-2.10.8
- see https://bugzilla.mozilla.org/show_bug.cgi?id=367203
- add thunderbird-scim_crach.patch for crashing with SCIM input
- see https://bugzilla.novell.com/show_bug.cgi?id=216139

* Thu Dec 21 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.5.0.9-1m)
- update to 1.5.0.9
-[SECURITY] MFSA 2006-74 MFSA 2006-73 MFSA 2006-72 MFSA 2006-71 MFSA 2006-70
            MFSA 2006-69 MFSA 2006-68

* Thu Nov  9 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.5.0.8-1m)
-[SECURITY] MFSA 2006-67 MFSA 2006-66 MFSA 2006-65

* Sat Sep 16 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.5.0.7-1m)
-[SECURITY] MFSA 2006-64 MFSA 2006-63 MFSA 2006-60 MFSA 2006-59 MFSA 2006-58 
            MFSA 2006-57 
- http://www.mozilla.org/projects/security/known-vulnerabilities.html#thunderbird1.5.0.7
- remove Patch90:thunderbird-mime_extern.patch

* Sun Jul 30 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.5.0.5-1m)
- [SECURITY] MFSA-2006-55 MFSA-2006-54 MFSA-2006-53 MFSA-2006-52 MFSA-2006-51
-            MFSA-2006-50 MFSA-2006-49 MFSA-2006-48 MFSA-2006-47 MFSA-2006-46
-            MFSA-2006-44
- http://www.mozilla.org/projects/security/known-vulnerabilities.html#thunderbird1.5.0.5

* Sat Jun 24 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (1.5.0.4-2m)
- add extern patch. need new gcc.

* Sun Jun 18 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.5.0.4-1m)
- [SECURITY] MFSA-2006-42 MFSA-2006-40 MFSA-2006-38 MFSA-2006-37 MFSA-2006-35
-            MFSA-2006-33 MFSA-2006-32 MFSA-2006-31
- http://www.mozilla.org/projects/security/known-vulnerabilities.html#thunderbird1.5.0.4

* Sat Apr 22 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.5.0.2-2m)
- add Source1: thunderbird-langpacks-1.5.0.2-20060419.tar.bz2

* Fri Apr 21 2006 Kazuhiko <kazuhiko@fdiary.net>
- (1.5.0.2-1m)
- [SECURITY] MFSA-2006-28 MFSA-2006-26 MFSA-2006-25 MFSA-2006-24 
-            MFSA-2006-22 MFSA-2006-20
- http://www.mozilla.org/projects/security/known-vulnerabilities.html#Thunderbird
- remove 'firefox-1.5.0.1-dumpstack.patch'
- remove 'firefox-bug305970.patch'

* Wed Mar 29 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (1.5-1m)
- update to 1.5
- sync with Fedora Core (1.5-6), now it can switch UI locale depending on system locale.
- - * Mon Mar 13 2006 Christopher Aillon <caillon@redhat.com> - 1.5.6
- - - Temporarily disable other arches that we don't ship FC5 with, for time
- - 
- - * Mon Mar 13 2006 Christopher Aillon <caillon@redhat.com> - 1.5-5
- - - Add a notice to the mail start page denoting this is a pango enabled build.
- - 
- - * Fri Feb 10 2006 Christopher Aillon <caillon@redhat.com> - 1.5-3
- - - Add dumpstack.patch
- - - Improve the langpack install stuff
- - 
- - * Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.5-2.1
- - - rebuilt for new gcc4.1 snapshot and glibc changes
- - 
- - * Fri Jan 27 2006 Christopher Aillon <caillon@redhat.com> - 1.5-2
- - - Add some langpacks back in
- - - Stop providing MozillaThunderbird
- - 
- - * Thu Jan 12 2006 Christopher Aillon <caillon@redhat.com> - 1.5-1
- - - Official 1.5 release is out
- - 
- - * Wed Jan 11 2006 Christopher Aillon <caillon@redhat.com> - 1.5-0.5.6.rc1
- - - Fix crash when deleting highlighted text while composing mail within
- -   plaintext editor with spellcheck enabled.
- - 
- - * Tue Jan  3 2006 Christopher Aillon <caillon@redhat.com> - 1.5-0.5.5.rc1
- - - Looks like we can build on ppc64 again.
- - 
- - * Fri Dec 16 2005 Christopher Aillon <caillon@redhat.com> - 1.5-0.5.4.rc1
- - - Rebuild
- - 
- - * Fri Dec 16 2005 Christopher Aillon <caillon@redhat.com> - 1.5-0.5.3.rc1
- - - Once again, disable ppc64 because of a new issue.
- -   See https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=175944
- - 
- - - Use the system NSS libraries
- - - Build on ppc64
- - 
- - * Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- - - rebuilt
- - 
- - * Mon Nov 28 2005 Christopher Aillon <caillon@redhat.com> - 1.5-0.5.1.rc1
- - - Fix issue with popup dialogs and other actions causing lockups
- - 
- - * Sat Nov  5 2005 Christopher Aillon <caillon@redhat.com> 1.5-0.5.0.rc1
- - - Update to 1.5 rc1
- - 
- - * Sat Oct  8 2005 Christopher Aillon <caillon@redhat.com> 1.5-0.5.0.beta2
- - - Update to 1.5 beta2
- - 
- - * Wed Sep 28 2005 Christopher Aillon <caillon@redhat.com> 1.5-0.5.0.beta1
- - - Update to 1.5 beta1
- - - Bring the install phase of the spec file up to speed

* Sun Mar 12 2006 Dai OKUYAMA <dai@ouchi.nahi.to>
- (1.0.7-4m)
- enable ppc64 build.
  (but maybe can't work...?)

* Tue Feb 28 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0.7-3m)
- import dumpstack.patch from opensuse
 +* Wed Jan 18 2006 - stark@suse.de
 +- fixed DumpStackToFile() for glibc 2.4

* Tue Nov  1 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.7-2m)
- add gcc4 patch
- Patch200: firefox-1.0-gcc4-compile.patch

* Fri Sep 30 2005 Kazuhiko <kazuhiko@fdiary.net>
- (1.0.7-1m)
- this version includes several security fixes
- remove too old 'release-notes.html'

* Wed Jul 20 2005 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.6-1m)
- up to 1.0.6

* Fri Jul 15 2005 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.0.5-1m)
- [SECURITY] MFSA 2005-56, MFSA 2005-44, MFSA 2005-41, ...

* Thu Mar 24 2005 Kazuhiko <kazuhiko@fdiary.net>
- (1.0.2-1m)
- security fix
-   http://www.mozilla.org/security/announce/mfsa2005-30.html

* Tue Feb 15 2005 Toru Hoshina <t@momonga-linux.org>
- (1.0-2m)
- rebuild without freetype 1.

* Wed Dec  8 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (1.0-1m)
  update to 1.0
  
* Mon Nov 22 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (0.9-2m)
- apply 'thunderbird-0.9-freetype-2.1.9.patch'

* Sat Nov  6 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9-1m)
  update to 0.9

* Tue Nov  2 2004 Kazuhiko <kazuhiko@fdiary.net>
- (0.8-3m)
- remove '-fomit-frame-pointer' and '-ffast-math' from RPM_OPT_FLAGS

* Tue Nov 02 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (0.8-2m)
- revised Buildroot:

* Thu Sep 23 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.8-1m)
  imported from FC development.

* Thu Sep 16 2004 Christopher Aillon <caillon@redhat.com> 0.8.0-1
- Update to 0.8.0
- Remove enigmail
- Update BuildRequires
- Remove gcc34 and extension manager patches -- they are upstreamed.
- Fix for gnome-vfs2 error at component registration

* Fri Sep 03 2004 Christopher Aillon <caillon@redhat.com> 0.7.3-5
- Build with --disable-xprint

* Wed Sep 01 2004 David Hill <djh[at]ii.net> 0.7.3-4
- remove all Xvfb-related hacks

* Wed Sep 01 2004 Warren Togami <wtogami@redhat.com> 
- actually apply psfonts
- add mozilla gnome-uriloader patch to prevent build failure

* Tue Aug 31 2004 Warren Togami <wtogami@redhat.com> 0.7.3-3
- rawhide import
- apply NetBSD's freetype 2.1.8 patch
- apply psfonts patch
- remove BR on /usr/bin/ex, breaks beehive

* Tue Aug 31 2004 David Hill <djh[at]ii.net> 0.7.3-0.fdr.2
- oops, fix %%install

* Thu Aug 26 2004 David Hill <djh[at]ii.net> 0.7.3-0.fdr.1
- update to Thunderbird 0.7.3 and Enigmail 0.85.0
- remove XUL.mfasl on startup, add Debian enigmail patches
- add Xvfb hack for -install-global-extension

* Wed Jul 14 2004 David Hill <djh[at]ii.net> 0.7.2-0.fdr.0
- update to 0.7.2, just because it's there
- update gcc-3.4 patch (Kaj Niemi)
- add EM registration patch and remove instdir hack

* Sun Jul 04 2004 David Hill <djh[at]ii.net> 0.7.1-0.fdr.1
- re-add Enigmime 1.0.7, omit Enigmail until the Mozilla EM problems are fixed

* Wed Jun 30 2004 David Hill <djh[at]ii.net> 0.7.1-0.fdr.0
- update to 0.7.1
- remove Enigmail

* Mon Jun 28 2004 David Hill <djh[at]ii.net> 0.7-0.fdr.1
- re-enable Enigmail 0.84.1
- add gcc-3.4 patch (Kaj Niemi)
- use official branding (with permission)

* Fri Jun 18 2004 David Hill <djh[at]ii.net> 0.7-0.fdr.0
- update to 0.7
- temporarily disable Enigmail 0.84.1, make ftp links work (#1634)
- specify libdir, change BR for apt (V. Skytta, #1617)

* Tue May 18 2004 Warren Togami <wtogami@redhat.com> 0.6-0.fdr.5
- temporary workaround for enigmail skin "modern" bug

* Mon May 10 2004 David Hill <djh[at]ii.net> 0.6-0.fdr.4
- update to Enigmail 0.84.0 
- update launch script

* Mon May 10 2004 David Hill <djh[at]ii.net> 0.6-0.fdr.3
- installation directory now versioned
- allow root to run the program (for installing extensions)
- remove unnecessary %%pre and %%post
- remove separators, update mozconfig and launch script (M. Schwendt, #1460)

* Wed May 05 2004 David Hill <djh[at]ii.net> 0.6-0.fdr.2
- include Enigmail, re-add release notes
- delete %{_libdir}/thunderbird in %%pre

* Mon May 03 2004 David Hill <djh[at]ii.net> 0.6-0.fdr.1
- update to Thunderbird 0.6

* Fri Apr 30 2004 David Hill <djh[at]ii.net> 0.6-0.fdr.0.rc1
- update to Thunderbird 0.6 RC1
- add new icon, remove release notes

* Thu Apr 15 2004 David Hill <djh[at]ii.net> 0.6-0.fdr.0.20040415
- update to latest CVS, update mozconfig and %%build accordingly
- update to Enigmail 0.83.6
- remove x-remote and x86_64 patches
- build with -Os

* Thu Apr 15 2004 David Hill <djh[at]ii.net> 0.5-0.fdr.12
- update x-remote patch
- more startup script fixes

* Tue Apr 06 2004 David Hill <djh[at]ii.net> 0:0.5-0.fdr.11
- startup script fixes, and a minor cleanup

* Sun Apr 04 2004 Warren Togami <wtogami@redhat.com> 0:0.5-0.fdr.10
- Minor cleanups

* Sun Apr 04 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.8
- minor improvements to open-browser.sh and startup script
- update to latest version of Blizzard's x-remote patch

* Thu Mar 25 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.7
- update open-browser.sh, startup script, and BuildRequires

* Sun Mar 14 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.6
- update open-browser script, modify BuildRequires (Warren)
- add Blizzard's x-remote patch
- initial attempt at x-remote-enabled startup script

* Sun Mar 07 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.5
- refuse to run with excessive privileges

* Fri Feb 27 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.4
- add Mozilla x86_64 patch (Oliver Sontag)
- Enigmail source filenames now include the version
- modify BuildRoot

* Thu Feb 26 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.3
- use the updated official tarball

* Wed Feb 18 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.2
- fix %%prep script

* Mon Feb 16 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.1
- update Enigmail to 0.83.3
- use official source tarball (after removing the CRLFs)
- package renamed to thunderbird

* Mon Feb 09 2004 David Hill <djh[at]ii.net>	0:0.5-0.fdr.0
- update to 0.5
- check for lockfile before launching

* Fri Feb 06 2004 David Hill <djh[at]ii.net>
- update to latest cvs
- update to Enigmail 0.83.2

* Thu Jan 29 2004 David Hill <djh[at]ii.net>	0:0.4-0.fdr.5
- update to Enigmail 0.83.1
- removed Mozilla/Firebird script patching

* Sat Jan 03 2004 David Hill <djh[at]ii.net>	0:0.4-0.fdr.4
- add startup notification to .desktop file

* Thu Dec 25 2003 Warren Togami <warren@togami.com> 0:0.4-0.fdr.3
- open-browser.sh release 3
- patch broken /usr/bin/mozilla script during install
- dir ownership
- XXX: Source fails build on x86_64... fix later

* Tue Dec 23 2003 David Hill <djh[at]ii.net>	0:0.4-0.fdr.2
- update to Enigmail 0.82.5
- add Warren's open-browser.sh (#1113)

* Tue Dec 09 2003 David Hill <djh[at]ii.net>	0:0.4-0.fdr.1
- use Thunderbird's mozilla-xremote-client to launch browser

* Sun Dec 07 2003 David Hill <djh[at]ii.net>	0:0.4-0.fdr.0
- update to 0.4
- make hyperlinks work (with recent versions of Firebird/Mozilla)

* Thu Dec 04 2003 David Hill <djh[at]ii.net>
- update to 0.4rc2

* Wed Dec 03 2003 David Hill <djh[at]ii.net>
- update to 0.4rc1 and Enigmail 0.82.4

* Thu Nov 27 2003 David Hill <djh[at]ii.net>
- update to latest CVS and Enigmail 0.82.3

* Sun Nov 16 2003 David Hill <djh[at]ii.net>
- update to latest CVS (0.4a)
- update Enigmail to 0.82.2
- alter mozconfig for new build requirements
- add missing BuildReq (#987)

* Thu Oct 16 2003 David Hill <djh[at]ii.net>	0:0.3-0.fdr.0
- update to 0.3

* Sun Oct 12 2003 David Hill <djh[at]ii.net>	0:0.3rc3-0.fdr.0
- update to 0.3rc3
- update Enigmail to 0.81.7

* Thu Oct 02 2003 David Hill <djh[at]ii.net>	0:0.3rc2-0.fdr.0
- update to 0.3rc2

* Wed Sep 17 2003 David Hill <djh[at]ii.net>	0:0.2-0.fdr.2
- simplify startup script

* Wed Sep 10 2003 David Hill <djh[at]ii.net>	0:0.2-0.fdr.1
- add GPG support (Enigmail 0.81.6)
- specfile fixes (#679)

* Thu Sep 04 2003 David Hill <djh[at]ii.net>	0:0.2-0.fdr.0
- update to 0.2

* Mon Sep 01 2003 David Hill <djh[at]ii.net>
- initial RPM
  (based on the fedora MozillaFirebird-0.6.1 specfile)

